public inbox for cygwin-cvs@sourceware.org
help / color / mirror / Atom feed
* [newlib-cygwin/main] Cygwin: fix two comments in heap.cc and memory_layout.h
@ 2023-01-18 19:35 Corinna Vinschen
  0 siblings, 0 replies; only message in thread
From: Corinna Vinschen @ 2023-01-18 19:35 UTC (permalink / raw)
  To: cygwin-cvs

https://sourceware.org/git/gitweb.cgi?p=newlib-cygwin.git;h=3c2ac163da888cf69d855c9becf643dbc6ebd94f

commit 3c2ac163da888cf69d855c9becf643dbc6ebd94f
Author:     Corinna Vinschen <corinna@vinschen.de>
AuthorDate: Wed Jan 18 20:07:54 2023 +0100
Commit:     Corinna Vinschen <corinna@vinschen.de>
CommitDate: Wed Jan 18 20:13:38 2023 +0100

    Cygwin: fix two comments in heap.cc and memory_layout.h
    
    Signed-off-by: Corinna Vinschen <corinna@vinschen.de>

Diff:
---
 winsup/cygwin/local_includes/memory_layout.h | 3 +--
 winsup/cygwin/mm/heap.cc                     | 4 ++--
 2 files changed, 3 insertions(+), 4 deletions(-)

diff --git a/winsup/cygwin/local_includes/memory_layout.h b/winsup/cygwin/local_includes/memory_layout.h
index c763442a9ef4..f8ec80bb58db 100644
--- a/winsup/cygwin/local_includes/memory_layout.h
+++ b/winsup/cygwin/local_includes/memory_layout.h
@@ -16,8 +16,7 @@ details. */
    dynamicbase is accidentally not set in the PE/COFF header of the DLL. */
 #define CYGWIN_DLL_ADDRESS		0x180040000UL
 
-/* Area for non-fixed-address Cygwin-specific shared memory regions.  Fallback
-   for standard shared regions if the can't load at their default address. */
+/* Area for Cygwin-specific shared memory regions. */
 #define SHARED_REGIONS_ADDRESS_LOW	0x1a0000000UL
 #define SHARED_REGIONS_ADDRESS_HIGH	0x200000000UL
 
diff --git a/winsup/cygwin/mm/heap.cc b/winsup/cygwin/mm/heap.cc
index 5b24a197f3b7..72ea486f38f1 100644
--- a/winsup/cygwin/mm/heap.cc
+++ b/winsup/cygwin/mm/heap.cc
@@ -77,11 +77,11 @@ user_heap_info::init ()
 	  if (base)
 	    break;
 
 	  /* Ok, so we are at the 1% which didn't work with 0x20000000 out
 	     of the box.  What we do now is to search for the next free
 	     region which matches our desired heap size.  While doing that,
 	     we keep track of the largest region we found, including the
-	     region starting at 0x20000000. */
+	     region starting at USERHEAP_START. */
 	  while ((ret = VirtualQuery ((LPCVOID) start_address, &mbi,
 				      sizeof mbi)) != 0)
 	    {

^ permalink raw reply	[flat|nested] only message in thread

only message in thread, other threads:[~2023-01-18 19:35 UTC | newest]

Thread overview: (only message) (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
@@ -77,11 +77,11 @@ user_heap_info::init ()
 	    break;
 
-	  /* Ok, so we are at the 1% which didn't work with 0x20000000 out
+	  /* Ok, so we are at the 1% which didn't work with USERHEAP_START out
 	     of the box.  What we do now is to search for the next free
 	     region which matches our desired heap size.  While doing that,
2023-01-18 19:35 [newlib-cygwin/main] Cygwin: fix two comments in heap.cc and memory_layout.h Corinna Vinschen

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).